# -*- coding: utf-8 -*-
# @Time     : 2021/4/22 19:04
# @Author   : ufy
# @Email    : antarm@outlook.com / 549147808@qq.com
# @file     : __init__.py
# @info     :

__version__ = '0.1.0'

print('ufy version:',__version__)