# -*- coding: utf-8 -*-
# @Time     : 2021/4/22 19:36
# @Author   : ufy
# @Email    : antarm@outlook.com / 549147808@qq.com
# @file     : setup.py.py
# @info     :

from setuptools import setup
setup(name='ufy',
      version = '0.1.2',
      description = 'some tools for ufy',
      author = 'ufy',
      author_eamil = 'antarm@outlook.com',
      url = 'https://github.com/antarm/ufy',
      packages=['ufy','ufy.core','ufy.core.ML','ufy.core.DL','ufy.core.ML.compaction','ufy.CV','ufy.datasets','ufy.utils','ufy.HX','ufy.HX.data_process'])